@@ -8,8 +8,9 @@ function(lib, pkg)
     ver <- package.description("tseries", lib = mylib)["Version"]
     vertxt <- paste("\n\t`tseries' version:", ver, "\n")
     introtxt <-
-        paste("\n\t`tseries' is a package for time series analysis.\n",
-              "\tSee `library (help=tseries)' for details.\n\n",
+        paste("\n\t`tseries' is a package for time series analysis\n",
+              "\t and computational finance.\n",
+              "\t See `library (help=tseries)' for details.\n\n",
               sep = "")
     if(interactive() || getOption("verbose"))
         cat(paste(vertxt, introtxt))
